# dirstruct

[![PyPi Version](https://img.shields.io/pypi/v/dirstruct.svg?style=flat-square)](https://pypi.org/project/dirstruct)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/dirstruct.svg?style=flat-square)](https://pypi.org/pypi/dirstruct/)
[![GitHub stars](https://img.shields.io/github/stars/nschloe/dirstruct.svg?style=flat-square&logo=github&label=Stars&logoColor=white)](https://github.com/nschloe/dirstruct)
[![PyPi downloads](https://img.shields.io/pypi/dm/dirstruct.svg?style=flat-square)](https://pypistats.org/packages/dirstruct)

[![gh-actions](https://img.shields.io/github/workflow/status/nschloe/dirstruct/ci?style=flat-square)](https://github.com/nschloe/dirstruct/actions?query=workflow%3Aci)
[![codecov](https://img.shields.io/codecov/c/github/nschloe/dirstruct.svg?style=flat-square)](https://codecov.io/gh/nschloe/dirstruct)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square)](https://github.com/psf/black)

Install with

```sh
pip install dirstruct
```
